@@ -39,11 +39,6 @@ test_format()
     OIIO_CHECK_EQUAL(Strutil::sprintf("%d", int64_t(0xffffffffffffffff)), "-1");
     OIIO_CHECK_EQUAL(Strutil::sprintf("%u", uint64_t(0xffffffffffffffff)), "18446744073709551615");
 
-#ifndef OIIO_HIDE_FORMAT
-    // spot check that Strutil::old::format() is sprintf:
-    OIIO_CHECK_EQUAL(Strutil::old::format("%d",1), "1");
-#endif
-
     // Test formatting with Strutil::fmt::format(), which uses the
     // Python conventions:
     OIIO_CHECK_EQUAL(Strutil::fmt::format("{} {:f} {}", int(3), 3.14f, 3.14f),
@@ -64,15 +59,6 @@ test_format()
     OIIO_CHECK_EQUAL(Strutil::fmt::format("{} {:f} {:g}", int(3), 3.14f, 3.14f),
                      "3 3.140000 3.14");
 
-#ifndef OIIO_HIDE_FORMAT
-    // Check that Strutil::format is aliased the right way
-#    if OIIO_FORMAT_IS_FMT
-    OIIO_CHECK_EQUAL(Strutil::format("{}", 1), "1");
-#    else
-    OIIO_CHECK_EQUAL(Strutil::format("%d", 1), "1");
-#    endif
-#endif
-
     Benchmarker bench;
     bench.indent (2);
     bench.units (Benchmarker::Unit::ns);
@@ -464,12 +450,16 @@ test_comparisons()
     OIIO_CHECK_EQUAL(Strutil::ifind("abcdeabcde", "BC"), 1);
     OIIO_CHECK_EQUAL(Strutil::ifind("abcdeabcde", "ac"), std::string::npos);
     OIIO_CHECK_EQUAL(Strutil::ifind("abcdeabcde", ""), 0);
+    OIIO_CHECK_EQUAL(Strutil::ifind("Xabcdeabcde", "x"), 0);
+    OIIO_CHECK_EQUAL(Strutil::ifind("abcdeabcdeX", "x"), 10);
     OIIO_CHECK_EQUAL(Strutil::ifind("", "abc"), std::string::npos);
     OIIO_CHECK_EQUAL(Strutil::ifind("", ""), std::string::npos);
     OIIO_CHECK_EQUAL(Strutil::irfind("abcdeabcde", "bc"), 6);
     OIIO_CHECK_EQUAL(Strutil::irfind("abcdeabcde", "BC"), 6);
     OIIO_CHECK_EQUAL(Strutil::irfind("abcdeabcde", "ac"), std::string::npos);
     OIIO_CHECK_EQUAL(Strutil::irfind("abcdeabcde", ""), 10);
+    OIIO_CHECK_EQUAL(Strutil::irfind("Xabcdeabcde", "x"), 0);
+    OIIO_CHECK_EQUAL(Strutil::irfind("abcdeabcdeX", "x"), 10);
     OIIO_CHECK_EQUAL(Strutil::irfind("", "abc"), std::string::npos);
     OIIO_CHECK_EQUAL(Strutil::irfind("", ""), std::string::npos);
 
@@ -901,6 +891,7 @@ test_numeric_conversion()
     OIIO_CHECK_EQUAL(Strutil::stoi("-12345678901234567890"),
                      std::numeric_limits<int>::min());
     OIIO_CHECK_EQUAL(Strutil::stoi("0x100", nullptr, 16), 256);  // hex
+    OIIO_CHECK_EQUAL(Strutil::stoi("25555555555555555551"), 2147483647);
 
     OIIO_CHECK_EQUAL(Strutil::stoui("hi"), 0);
     OIIO_CHECK_EQUAL(Strutil::stoui("  "), 0);
@@ -1324,7 +1315,7 @@ test_string_view()
     OIIO_CHECK_EQUAL(OIIO::c_str(string_view(sr.data(), 2)), std::string("01"));
     Strutil::print("addr cstr={:p}, s={:p}, ustring={:p}, sr={:p}, c_str(sr)={:p}\n",
                      (void*)cstr, (void*)s.c_str(), (void*)ustring(cstr).c_str(), (void*)sr.data(),
-                     (void*)c_str(sr));
+                     (void*)OIIO::c_str(sr));
 }
 
 
